FlanaUtils
==========

|license| |project_version| |python_version|

Flanagan's utils.

Installation
------------

Python 3.10 or higher is required.

.. code-block::

    pip install flanautils


.. |license| image:: https://img.shields.io/github/license/AlberLC/flanautils?style=flat
    :target: https://github.com/AlberLC/flanautils/blob/main/LICENSE
    :alt: License

.. |project_version| image:: https://img.shields.io/pypi/v/flanautils
    :target: https://pypi.org/project/flanautils/
    :alt: PyPI

.. |python_version| image:: https://img.shields.io/pypi/pyversions/flanautils
    :target: https://www.python.org/downloads/
    :alt: PyPI - Python Version